/*******************************************************************************
* Copyright 2009 Seapine Software, Inc. All rights reserved.
*
* IMPORTANT:  This Software is supplied to you by Seapine Software, Inc. (Seapine)
* in consideration of your agreement to the following terms, and your use, installation,
* modification or redistribution of this Software constitutes acceptance of these terms.
* If you do not agree with these terms, please do not use, install, modify or redistribute
* this Software.
*
* In consideration of your agreement to abide by the following terms, and subject to these
* terms, Seapine grants you a personal, non-exclusive license, under Seapine copyrights in
* this original Seapine software (the Software), to use, reproduce, modify and redistribute
* the Software, with or without modifications, in source and/or binary forms; provided that
* if you redistribute the Software in its entirety and without modifications, you must retain
* this notice and the following text and disclaimers in all such redistributions of the Software.
* Neither the name, trademarks, service marks or logos of Seapine, Inc. may be used to endorse
* or promote products derived from the Software without specific prior written permission from
* Seapine.  Except as expressly stated in this notice, no other rights or licenses, express or
* implied, are granted by Seapine herein, including but not limited to any patent rights that
* may be infringed by your derivative works or by other works in which the Software may be
* incorporated.
*
* The Software is provided by Seapine on an "AS IS" basis.  SEAPINE MAKES NO WARRANTIES,
* EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION THE IMPLIED WARRANTIES OF NON-INFRINGEMENT,
* MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE, REGARDING THE SOFTWARE OR ITS USE AND
* OPERATION ALONE OR IN COMBINATION WITH YOUR PRODUCTS.
*
* IN NO EVENT SHALL SEAPINE BE LIABLE FOR ANY SPECIAL, INDIRECT, INCIDENTAL OR CONSEQUENTIAL
* DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) ARISING IN ANY WAY OUT OF THE USE,
* REPRODUCTION, MODIFICATION AND/OR DISTRIBUTION OF THE SOFTWARE, HOWEVER CAUSED AND WHETHER
* UNDER THEORY OF CONTRACT, TORT (INCLUDING NEGLIGENCE), STRICT LIABILITY OR OTHERWISE, EVEN
* IF SEAPINE HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
******************************************************************************/
using System;
using System.Collections.Generic;
using System.IO;
using System.Text;
using System.Xml;

namespace JiraViewer
{
    public class Config
    {
        protected Logger logger = null;

        public String appPath = "";
        public String fileName = "";
        public void SetPath(string path)
        {
            appPath = path;
            fileName = appPath + "\\Config.xml";
        }

        public bool Exists()
        {

            FileInfo configFile = new FileInfo(fileName);
            if (configFile.Exists)
            {
                return (true);
            }
            else
            {
                return (false);
            }
            
                        
        }
        //Methods for individual values
        //'get' methods are used to retrieve data from configuration file
        public string getJIRAURLFromFile()
        {
            string jiraURL = "";
            try
            {

                XmlDocument mDocument;
                XmlNode mCurrentNode;

                mDocument = new XmlDocument();
                mDocument.Load(fileName);
                mCurrentNode = mDocument.DocumentElement;

                mCurrentNode = mCurrentNode.SelectSingleNode("//ServerAddress");
                jiraURL = mCurrentNode.InnerText;

               
            }
            catch (Exception f)
            {
                Logger.WriteLine("Error retrieving the TestTrack SOAP URL form the configuration file:\n" + f.Message);
            }
            return (jiraURL);
            
        }        
        public string getProjectFromFile()
        {
            string jiraProject = "";

            try
            {

                XmlDocument mDocument;
                XmlNode mCurrentNode;

                mDocument = new XmlDocument();
                mDocument.Load(fileName);
                mCurrentNode = mDocument.DocumentElement;
                mCurrentNode = mCurrentNode.SelectSingleNode("//Project");
                jiraProject = mCurrentNode.InnerText;
            }
            catch (Exception f)
            {
                Logger.WriteLine("Error retrieving the Jira project name form the configuration file:\n" + f.Message);
            }
            return (jiraProject);
        }
        public string getUserNameFromFile()
        {
            string jiraUserName = "";
            try
            {
                XmlDocument mDocument;
                XmlNode mCurrentNode;

                mDocument = new XmlDocument();
                mDocument.Load(fileName);
                mCurrentNode = mDocument.DocumentElement;
                mCurrentNode = mCurrentNode.SelectSingleNode("//UserName");
                jiraUserName = mCurrentNode.InnerText;
            }
            catch (Exception f)
            {
                Logger.WriteLine("Error retrieving the JIRA user name form the configuration file:\n" + f.Message);
            }
            return (jiraUserName);


        }

        public string getPasswordFromFile()
        {
            string jiraPassword = "";

            try
            {

                XmlDocument mDocument;
                XmlNode mCurrentNode;

                mDocument = new XmlDocument();
                mDocument.Load(fileName);
                mCurrentNode = mDocument.DocumentElement;
                mCurrentNode = mCurrentNode.SelectSingleNode("//Password");
                jiraPassword = mCurrentNode.InnerText;
            }
            catch (Exception f)
            {
                Logger.WriteLine("Error retrieving the JIRA password form the configuration file:\n" + f.Message);
            }
            return (jiraPassword);


        }
        public string getDefaultFilter()
        {
            string jiraFilter = "";
            try
            {

                XmlDocument mDocument;
                XmlNode mCurrentNode;

                mDocument = new XmlDocument();
                mDocument.Load(fileName);
                mCurrentNode = mDocument.DocumentElement;
                mCurrentNode = mCurrentNode.SelectSingleNode("//Filter");
                jiraFilter = mCurrentNode.InnerText;
            }
            catch (Exception f)
            {
                Logger.WriteLine("Error retrieving the default filter form the configuration file:\n" + f.Message);
            }
            return (jiraFilter);


        }
    }
}
