/*******************************************************************************
* Copyright 2009 Seapine Software, Inc. All rights reserved.
*
* IMPORTANT:  This Software is supplied to you by Seapine Software, Inc. (Seapine)
* in consideration of your agreement to the following terms, and your use, installation,
* modification or redistribution of this Software constitutes acceptance of these terms.
* If you do not agree with these terms, please do not use, install, modify or redistribute
* this Software.
*
* In consideration of your agreement to abide by the following terms, and subject to these
* terms, Seapine grants you a personal, non-exclusive license, under Seapine copyrights in
* this original Seapine software (the Software), to use, reproduce, modify and redistribute
* the Software, with or without modifications, in source and/or binary forms; provided that
* if you redistribute the Software in its entirety and without modifications, you must retain
* this notice and the following text and disclaimers in all such redistributions of the Software.
* Neither the name, trademarks, service marks or logos of Seapine, Inc. may be used to endorse
* or promote products derived from the Software without specific prior written permission from
* Seapine.  Except as expressly stated in this notice, no other rights or licenses, express or
* implied, are granted by Seapine herein, including but not limited to any patent rights that
* may be infringed by your derivative works or by other works in which the Software may be
* incorporated.
*
* The Software is provided by Seapine on an "AS IS" basis.  SEAPINE MAKES NO WARRANTIES,
* EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION THE IMPLIED WARRANTIES OF NON-INFRINGEMENT,
* MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE, REGARDING THE SOFTWARE OR ITS USE AND
* OPERATION ALONE OR IN COMBINATION WITH YOUR PRODUCTS.
*
* IN NO EVENT SHALL SEAPINE BE LIABLE FOR ANY SPECIAL, INDIRECT, INCIDENTAL OR CONSEQUENTIAL
* DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) ARISING IN ANY WAY OUT OF THE USE,
* REPRODUCTION, MODIFICATION AND/OR DISTRIBUTION OF THE SOFTWARE, HOWEVER CAUSED AND WHETHER
* UNDER THEORY OF CONTRACT, TORT (INCLUDING NEGLIGENCE), STRICT LIABILITY OR OTHERWISE, EVEN
* IF SEAPINE HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
******************************************************************************/
using System;
using System.Collections;
using System.Text;
using System.Data;
using System.Windows.Forms;

namespace JiraViewer
{
   public class JiraConnector
   {
      protected JiraSoapServiceService jiraEengine = null;
      protected string jiraSession = null;
      public DataTable jiras;
      public Hashtable jiraStates;
      public Hashtable jiraTypes;

      public void BuildHashTables()
      {
           jiraStates = new Hashtable();
           jiraTypes = new Hashtable();
           RemoteStatus[] jiraStatus = jiraEengine.getStatuses(jiraSession);
           for (int i = 0; i < jiraStatus.Length; i++)
           {
               jiraStates.Add(jiraStatus[i].id, jiraStatus[i].name);
           }
           RemoteIssueType[] jiraTypeValues = jiraEengine.getIssueTypes(jiraSession);
           for (int i = 0; i < jiraTypeValues.Length; i++)
           {
               jiraTypes.Add(jiraTypeValues[i].id, jiraTypeValues[i].name);
           }
           
           
      }
      public void AddComment(string body, string author, string jiraToken, string issueKey)
      {
          RemoteComment comment = new RemoteComment(); 
          comment.body = body; 
          comment.author = author; 
          comment.created = DateTime.Now; 
          comment.updated = DateTime.Now; 
          jiraEengine.addComment(jiraToken, issueKey, comment);

      }
      public JiraConnector()
      {
          jiraEengine = new JiraSoapServiceService();
         
      }
      public DataTable BuildIssueTable(RemoteIssue[] Issues)
      {
          
          BuildHashTables();
          DataTable jiraIssues = new DataTable("Issues");
          try
          {

              DataColumn[] jiraColumns = new DataColumn[6];
              jiraColumns[0] = new DataColumn();
              jiraColumns[0].ColumnName = "Key";
              jiraColumns[1] = new DataColumn();
              jiraColumns[1].ColumnName = "Type";
              jiraColumns[2] = new DataColumn();
              jiraColumns[2].ColumnName = "Summary";
              jiraColumns[3] = new DataColumn();
              jiraColumns[3].ColumnName = "Assignee";
              jiraColumns[4] = new DataColumn();
              jiraColumns[4].ColumnName = "Status";
              jiraColumns[5] = new DataColumn();
              jiraColumns[5].ColumnName = "Description";
             

              for (int i = 0; i < jiraColumns.Length; i++)
              {
                  jiraIssues.Columns.Add(jiraColumns[i]);
              }
              for (int i = 0; i < Issues.Length; i++)
              {
                  DataRow jiraRow = jiraIssues.NewRow();
                  jiraRow["Key"] = Issues[i].key;
                  jiraRow["Type"] = jiraTypes[Issues[i].type].ToString();
                  jiraRow["Summary"] = Issues[i].summary;
                  jiraRow["Assignee"] = Issues[i].assignee;
                  jiraRow["Status"] = jiraStates[Issues[i].status].ToString();
                  jiraRow["Description"] = Issues[i].description;
                  
                  jiraIssues.Rows.Add(jiraRow);
              }
          }
          catch (Exception fcc)
          {
              Logger.WriteLine(fcc.Message);
          }
          return jiraIssues;
      }
      public bool run(string p_strUrl, string p_strProject, string p_strUser, string p_strPwd, string p_strFilter)
      {

          if (p_strUrl.Length > 0)
          {
              jiraEengine.Url = p_strUrl; 
          }
          bool fResult = false;
          try
          {

              jiraSession = jiraEengine.login(p_strUser, p_strPwd);
              RemoteProject project = getProject(p_strProject);
              if (project == null)
              { 
                  Logger.WriteLine("Project '" + p_strProject + "' not found, so the JIRA viewer will now close.");
                  MessageBox.Show("Project '" + p_strProject + "' not found, so the JIRA viewer will now close.");
                  return (false); 
              }
              string filterID = "";
              string filtername = p_strFilter;
              RemoteFilter[] filters = jiraEengine.getSavedFilters(jiraSession);
              for (int i = 0; i < filters.Length; i++)
              {
                  if (filters[i].name.Equals(filtername))
                  {
                      filterID = filters[i].id;
                  }
              }
              RemoteIssue[] issues = jiraEengine.getIssuesFromFilter(jiraSession, filterID);
              jiras = BuildIssueTable(issues);
           
         }
         catch (Exception p_exception)
         {
             MessageBox.Show("Unable to retrieve list of issues: " + p_exception.Message);
             Logger.WriteLine("Unable to retrieve list of issues: " + p_exception.Message);
             Application.Exit();
         }
         finally
         {
             if (jiraSession != null)
             {
                 jiraEengine.logout(jiraSession);
             }
         }
         return (fResult);
      }

      protected  RemoteProject getProject(string p_strName)
      {
         RemoteProject proj = null;
         try
         {
             RemoteProject[] a = jiraEengine.getProjectsNoSchemes(jiraSession);
            for (int i = 0; a != null && i < a.Length; ++i) 
            { 
                if (a[i].name == p_strName) 
                { 
                    proj = a[i];
                    break; 
                } 
            }
         }
         catch (Exception p_exception)
         {
             Logger.WriteLine("Unable to find project '" + p_strName + "': " + p_exception.Message);
         }
         return (proj);
      }
   }
}
